/**
 * Author : xuqw
 *   Date : 2015年9月25日 下午6:33:28
 *
 * Copyright (C) 2015 Seeyon, Inc. All rights reserved.
 *
 * This software is the proprietary information of Seeyon, Inc.
 * Use is subject to license terms.
 */
package com.seeyon.apps.utils;

import java.lang.reflect.Field;
import java.lang.reflect.Method;

import org.apache.log4j.Logger;

import com.seeyon.ctp.common.AppContext;
import com.seeyon.ctp.common.controller.BaseController;

/**
 * <p>
 * Title : 应用模块名称
 * </p>
 * <p>
 * Description : 代码描述
 * </p>
 * <p>
 * Copyright : Copyright (c) 2015
 * </p>
 * <p>
 * Company : seeyon.com
 * </p>
 */
public class ControllerFactory {

    private static final Logger logger = Logger.getLogger(ControllerFactory.class);
    
    private static ControllerFactory factory = new ControllerFactory();

    private ControllerFactory() {

    }

    public static ControllerFactory getInstance() {

        return factory;
    }

    public <T extends BaseController> T generateController(Class<T> type){

        T controller = null;
        try {
            controller = type.newInstance();
        } catch (InstantiationException e1) {
            logger.error("", e1);
        } catch (IllegalAccessException e1) {
            logger.error("", e1);
        }

        Field[] fields = type.getDeclaredFields();
        for (Field f : fields) {
            String fName = f.getName();
            Class fType = f.getType();

            Object o = null;
            try {
                o = AppContext.getBean(fName);

                if (o != null && fType.isInstance(o)) {

                    String setMethod = "set"
                            + fName.substring(0, 1).toUpperCase()
                            + fName.substring(1);

                    Method method = type.getMethod(setMethod, fType);
                    method.invoke(controller, o);
                }
            } catch (Exception e) {
                // TODO: handle exception
            }
        }

        return controller;
    }
}
