/**
 * Author : xuqw
 *   Date : 2015年9月29日 上午9:43:05
 *
 * Copyright (C) 2015 Seeyon, Inc. All rights reserved.
 *
 * This software is the proprietary information of Seeyon, Inc.
 * Use is subject to license terms.
 */
package com.seeyon.apps.utils;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Locale;

import org.apache.log4j.Logger;

import com.seeyon.apps.http.SeeyonTestResponse;
import com.seeyon.ctp.common.AppContext;
import com.seeyon.ctp.common.authenticate.domain.User;
import com.seeyon.ctp.common.exceptions.BusinessException;
import com.seeyon.ctp.organization.bo.V3xOrgAccount;
import com.seeyon.ctp.organization.bo.V3xOrgMember;
import com.seeyon.ctp.organization.manager.OrgManager;

/**
 * <p>Title       : 应用模块名称</p>
 * <p>Description : 代码描述</p>
 * <p>Copyright   : Copyright (c) 2015</p>
 * <p>Company     : seeyon.com</p>
 */
public class SeeyonTestUtil {

    //Spring 相关的Bean
    private static OrgManager orgManager = null;
    
    private static final Logger logger = Logger.getLogger(SeeyonTestUtil.class);
    
    static{
        orgManager = (OrgManager) AppContext.getBean("orgManager");
    }
    
    /**
     * 关闭Response的输出流
     * @Author      : xuqw
     * @Date        : 2015年9月27日下午11:18:33
     * @param response
     */
    public static void closeResponseIO(SeeyonTestResponse response) {

        PrintWriter p = null;
        try {
            p = response.getWriter();
        } catch (IOException e) {
            logger.error("获取response的输出流异常", e);
        }
        if (p != null) {
            p.close();
        }
    }
    
    /**
     * 生成User对象， 并注入ThreadLocal
     * @Author      : xuqw
     * @Date        : 2015年9月24日下午9:26:10
     * @param member
     * @return
     * @throws BusinessException 
     */
    public static User createSessionUser(V3xOrgMember member) throws BusinessException {
        
        User user = null;
        if (member != null) {
            user = new User();
            user.setId(member.getId());
            user.setName(member.getName());
            user.setAccountId(member.getOrgAccountId());
            user.setDepartmentId(member.getOrgDepartmentId());
            user.setLoginName(member.getLoginName());
            
            //登录单位信息设置
            V3xOrgAccount account = orgManager.getAccountById(member.getOrgAccountId());
            
            user.setLoginAccount(account.getId());
            user.setLoginAccountName(account.getName());
            
            user.setRemoteAddr("127.0.0.1");
            user.setLocale(new Locale("zh","CN"));
        }
        return user;
    }
    
    /**
     * 生成一个14位的数
     * @Author      : xuqw
     * @Date        : 2015年10月13日下午5:41:12
     * @param n 1位的随机数
     * @return
     */
    public static long get14Id(int n){
        
        long time = System.currentTimeMillis();
        String ret = String.valueOf(time) + n;
        return Long.parseLong(ret);
    }
}
